@@ -1,6 +1,6 @@
 package Net::Google::WebmasterTools;
 {
-    $Net::Google::WebmasterTools::VERSION = '0.02';
+    $Net::Google::WebmasterTools::VERSION = '0.03';
 }
 use strict;
 
@@ -8,10 +8,10 @@ use strict;
 
 use JSON;
 use LWP::UserAgent;
+use Net::Google::WebmasterTools::Request;
 use Net::Google::WebmasterTools::Response;
 use Net::Google::WebmasterTools::Row;
 use URI;
-use URI::Encode qw(uri_encode);
 
 sub new {
     my $package = shift;
@@ -63,11 +63,11 @@ sub new_request {
 }
 
 sub _uri {
-    my ( $self, $req, $start_index, $row_limit ) = @_;
+    my ( $self, $req, $row_limit ) = @_;
 
     my $uri
         = URI->new( 'https://www.googleapis.com/webmasters/v3/sites/'
-            . uri_encode( $req->site_url ) . '/'
+            . $req->site_url . '/'
             . $req->report_name . '/'
             . $req->method );
     if (   ( $req->report_name =~ m{^(?:sitemaps|urlCrawlErrorsSamples)$} )
@@ -75,13 +75,12 @@ sub _uri {
     {
         $uri
             = URI->new( 'https://www.googleapis.com/webmasters/v3/sites/'
-                . uri_encode( $req->site_url ) . '/'
+                . $req->site_url . '/'
                 . $req->report_name );
     }
     elsif ( ( $req->report_name eq 'sites' ) && ( $req->method eq 'list' ) ) {
         $uri = URI->new('https://www.googleapis.com/webmasters/v3/sites');
     }
-
     return $uri;
 }
 
@@ -151,47 +150,6 @@ sub retrieve {
     return $self->_retrieve( $req, $req->start_index, $req->row_limit );
 }
 
-sub retrieve_paged {
-    my ( $self, $req ) = @_;
-
-    my $start_index = $req->start_index;
-    $start_index = 1 if !defined($start_index);
-    my $remaining_items    = $req->row_limit;
-    my $max_items_per_page = 10_000;
-    my $res;
-
-    while ( !defined($remaining_items) || $remaining_items > 0 ) {
-        my $row_limit = defined($remaining_items)
-            && $remaining_items < $max_items_per_page
-            ? $remaining_items
-            : $max_items_per_page;
-
-        my $page = $self->_retrieve( $req, $start_index, $row_limit );
-        return $page if !$page->is_success;
-
-        if ( !defined($res) ) {
-            $res = $page;
-        }
-        else {
-            push( @{ $res->rows }, @{ $page->rows } );
-        }
-
-        my $num_items = @{ $page->rows };
-        last if $num_items < $row_limit;
-
-        $remaining_items -= $num_items if defined($remaining_items);
-        $start_index += $num_items;
-    }
-
-    my $total_items = @{ $res->rows };
-    $res->items_per_page($total_items);
-
-    # The total result count of the first page isn't always accurate
-    $res->total_results($total_items);
-
-    return $res;
-}
-
 1;
 
 __END__
@@ -202,11 +160,11 @@ __END__
 
 =head1 NAME
 
-Net::Google::WebmasterTools - Simple interface to the Google WebmasterTools Core Reporting API
+Net::Google::WebmasterTools - Simple interface to the Google Webmaster Tools (Search Console) Core Reporting API
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -238,8 +196,8 @@ version 0.02
         method       => "query",
         dimensions   => ['country','device'],
         search_type  => 'web',
-        start_date   => "2015-08-01",
-        end_date     => "2015-08-31",
+        start_date   => "2019-05-01",
+        end_date     => "2019-05-31",
         row_limit    => 1000,
     );
 
@@ -275,7 +233,7 @@ Net::Google::WebmasterTools - Simple interface to the Google Webmaster Tools (Se
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 GETTING STARTED
 
